# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.api.jwt_token_auth_api import JwtTokenAuthApi


class TestJwtTokenAuthApi(unittest.IsolatedAsyncioTestCase):
    """JwtTokenAuthApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = JwtTokenAuthApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_jwt_token_auth_count_keys(self) -> None:
        """Test case for jwt_token_auth_count_keys

        Count Keys
        """
        pass

    async def test_jwt_token_auth_count_logs(self) -> None:
        """Test case for jwt_token_auth_count_logs

        Count Logs
        """
        pass

    async def test_jwt_token_auth_count_permission_categories(self) -> None:
        """Test case for jwt_token_auth_count_permission_categories

        Count Permission Categories
        """
        pass

    async def test_jwt_token_auth_create_key(self) -> None:
        """Test case for jwt_token_auth_create_key

        Create Key
        """
        pass

    async def test_jwt_token_auth_delete_key(self) -> None:
        """Test case for jwt_token_auth_delete_key

        Delete Key
        """
        pass

    async def test_jwt_token_auth_get_key(self) -> None:
        """Test case for jwt_token_auth_get_key

        Get Key
        """
        pass

    async def test_jwt_token_auth_get_key_specification_url(self) -> None:
        """Test case for jwt_token_auth_get_key_specification_url

        Get Key Specification Url
        """
        pass

    async def test_jwt_token_auth_get_keys(self) -> None:
        """Test case for jwt_token_auth_get_keys

        Get Keys
        """
        pass

    async def test_jwt_token_auth_get_log(self) -> None:
        """Test case for jwt_token_auth_get_log

        Get Log
        """
        pass

    async def test_jwt_token_auth_get_logs(self) -> None:
        """Test case for jwt_token_auth_get_logs

        Get Logs
        """
        pass

    async def test_jwt_token_auth_get_permission_categories(self) -> None:
        """Test case for jwt_token_auth_get_permission_categories

        Get Permission Categories
        """
        pass

    async def test_jwt_token_auth_patch_key(self) -> None:
        """Test case for jwt_token_auth_patch_key

        Patch Key
        """
        pass

    async def test_jwt_token_auth_update_key(self) -> None:
        """Test case for jwt_token_auth_update_key

        Update Key
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.api.api_logs_api import ApiLogsApi


class TestApiLogsApi(unittest.IsolatedAsyncioTestCase):
    """ApiLogsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ApiLogsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_jwt_token_auth_count_logs(self) -> None:
        """Test case for jwt_token_auth_count_logs

        Count Logs
        """
        pass

    async def test_jwt_token_auth_get_log(self) -> None:
        """Test case for jwt_token_auth_get_log

        Get Log
        """
        pass

    async def test_jwt_token_auth_get_logs(self) -> None:
        """Test case for jwt_token_auth_get_logs

        Get Logs
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.course_module import CourseModule

class TestCourseModule(unittest.TestCase):
    """CourseModule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CourseModule:
        """Test CourseModule
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CourseModule`
        """
        model = CourseModule()
        if include_optional:
            return CourseModule(
                mandatory = True,
                is_published = True,
                is_active = True,
                title = '',
                public_description = '',
                short_description = '',
                image_id = '',
                available_at = 56,
                id = 56,
                course_id = 56,
                order = 56,
                submodules = [
                    public_api_server_connector_v2.models.course_submodule.CourseSubmodule(
                        order = 56, 
                        title = '', 
                        is_published = True, 
                        id = 56, 
                        module_id = 56, 
                        created_at = 56, )
                    ],
                lessons = [
                    public_api_server_connector_v2.models.module_lesson.ModuleLesson(
                        submodule_id = 56, 
                        thread_id = 56, 
                        lesson_type = null, 
                        image_id = '', 
                        title = '', 
                        payload = '', 
                        is_active = True, 
                        is_published = True, 
                        mandatory = True, 
                        id = 56, 
                        module_id = 56, 
                        order = 56, 
                        public_key = '', 
                        content_blocks = [
                            public_api_server_connector_v2.models.content_block.ContentBlock(
                                block_type = null, 
                                order = 56, 
                                is_expanded = True, 
                                content = null, 
                                id = 56, 
                                lesson_id = 56, 
                                created_at = 56, )
                            ], 
                        attached_files = [
                            public_api_server_connector_v2.models.attached_file.AttachedFile(
                                order = 56, 
                                file_id = 56, 
                                id = 56, 
                                lesson_id = 56, 
                                created_at = 56, )
                            ], )
                    ]
            )
        else:
            return CourseModule(
                title = '',
                id = 56,
                course_id = 56,
                order = 56,
                submodules = [
                    public_api_server_connector_v2.models.course_submodule.CourseSubmodule(
                        order = 56, 
                        title = '', 
                        is_published = True, 
                        id = 56, 
                        module_id = 56, 
                        created_at = 56, )
                    ],
                lessons = [
                    public_api_server_connector_v2.models.module_lesson.ModuleLesson(
                        submodule_id = 56, 
                        thread_id = 56, 
                        lesson_type = null, 
                        image_id = '', 
                        title = '', 
                        payload = '', 
                        is_active = True, 
                        is_published = True, 
                        mandatory = True, 
                        id = 56, 
                        module_id = 56, 
                        order = 56, 
                        public_key = '', 
                        content_blocks = [
                            public_api_server_connector_v2.models.content_block.ContentBlock(
                                block_type = null, 
                                order = 56, 
                                is_expanded = True, 
                                content = null, 
                                id = 56, 
                                lesson_id = 56, 
                                created_at = 56, )
                            ], 
                        attached_files = [
                            public_api_server_connector_v2.models.attached_file.AttachedFile(
                                order = 56, 
                                file_id = 56, 
                                id = 56, 
                                lesson_id = 56, 
                                created_at = 56, )
                            ], )
                    ],
        )
        """

    def testCourseModule(self):
        """Test CourseModule"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
